==> libjogl2-java_2.5.0+dfsg.orig.tar.xz: jogl-v2.5.0/src/demos/com/jogamp/opengl/demos/android/NEWTGearsES2TransActivityLauncher.java <==
package com.jogamp.opengl.demos.android;

import java.util.Arrays;
import java.util.List;

import com.jogamp.opengl.demos.android.LauncherUtil.OrderedProperties;

public class NEWTGearsES2TransActivityLauncher extends LauncherUtil.BaseActivityLauncher {
    static String demo = "com.jogamp.opengl.test.android.NEWTGearsES2TransActivity";
    static String[] sys_pkgs = new String[] { "com.jogamp.common", "com.jogamp.opengl" };
    static String[] usr_pkgs = new String[] { "com.jogamp.opengl.test" };

    @Override
    public void init() {
       final OrderedProperties props = getProperties();
       // props.setProperty("jnlp.android.translucent", "true");
       // props.setProperty("jogamp.debug.JNILibLoader", "true");
       // props.setProperty("jogamp.debug.NativeLibrary", "true");
       // properties.setProperty("jogamp.debug.NativeLibrary.Lookup", "true");
       // properties.setProperty("jogamp.debug.IOUtil", "true");
       // properties.setProperty("nativewindow.debug", "all");
       props.setProperty("nativewindow.debug.GraphicsConfiguration", "true");
       // properties.setProperty("jogl.debug", "all");
       // properties.setProperty("jogl.debug.GLProfile", "true");
       props.setProperty("jogl.debug.GLDrawable", "true");
       props.setProperty("jogl.debug.GLContext", "true");
       props.setProperty("jogl.debug.GLSLCode", "true");
       props.setProperty("jogl.debug.CapabilitiesChooser", "true");
       // properties.setProperty("jogl.debug.GLSLState", "true");
       // properties.setProperty("jogl.debug.DebugGL", "true");
       // properties.setProperty("jogl.debug.TraceGL", "true");
       // properties.setProperty("newt.debug", "all");
       props.setProperty("newt.debug.Window", "true");
       // properties.setProperty("newt.debug.Window.MouseEvent", "true");
       // properties.setProperty("newt.debug.Window.KeyEvent", "true");
       props.setProperty("jogamp.debug.IOUtil", "true");
    }

    @Override
    public String getActivityName() {
        return demo;
    }

    @Override
    public List<String> getSysPackages() {
        return Arrays.asList(sys_pkgs);
    }

    @Override
    public List<String> getUsrPackages() {
        return Arrays.asList(usr_pkgs);
    }

    @Override
    public String getAction() {
        return LauncherUtil.LAUNCH_ACTIVITY_TRANSPARENT;
    }
}

==> libjogl2-java_2.6.0+dfsg.orig.tar.xz: jogl-v2.6.0/src/demos/com/jogamp/opengl/demos/android/NEWTGearsES2TransActivityLauncher.java <==
package com.jogamp.opengl.demos.android;

import java.util.Arrays;
import java.util.List;

import com.jogamp.opengl.demos.android.LauncherUtil.OrderedProperties;

public class NEWTGearsES2TransActivityLauncher extends LauncherUtil.BaseActivityLauncher {
    static String demo = "com.jogamp.opengl.demos.android.NEWTGearsES2TransActivity";
    static String[] sys_pkgs = new String[] { "com.jogamp.common", "com.jogamp.opengl" };
    static String[] usr_pkgs = new String[] { "com.jogamp.opengl.demos" };

    @Override
    public void init() {
       final OrderedProperties props = getProperties();
       // props.setProperty("jnlp.android.translucent", "true");
       // props.setProperty("jogamp.debug.JNILibLoader", "true");
       // props.setProperty("jogamp.debug.NativeLibrary", "true");
       // properties.setProperty("jogamp.debug.NativeLibrary.Lookup", "true");
       // properties.setProperty("jogamp.debug.IOUtil", "true");
       // properties.setProperty("nativewindow.debug", "all");
       props.setProperty("nativewindow.debug.GraphicsConfiguration", "true");
       // properties.setProperty("jogl.debug", "all");
       // properties.setProperty("jogl.debug.GLProfile", "true");
       props.setProperty("jogl.debug.GLDrawable", "true");
       props.setProperty("jogl.debug.GLContext", "true");
       props.setProperty("jogl.debug.GLSLCode", "true");
       props.setProperty("jogl.debug.CapabilitiesChooser", "true");
       // properties.setProperty("jogl.debug.GLSLState", "true");
       // properties.setProperty("jogl.debug.DebugGL", "true");
       // properties.setProperty("jogl.debug.TraceGL", "true");
       // properties.setProperty("newt.debug", "all");
       props.setProperty("newt.debug.Window", "true");
       // properties.setProperty("newt.debug.Window.MouseEvent", "true");
       // properties.setProperty("newt.debug.Window.KeyEvent", "true");
       props.setProperty("jogamp.debug.IOUtil", "true");
    }

    @Override
    public String getActivityName() {
        return demo;
    }

    @Override
    public List<String> getSysPackages() {
        return Arrays.asList(sys_pkgs);
    }

    @Override
    public List<String> getUsrPackages() {
        return Arrays.asList(usr_pkgs);
    }

    @Override
    public String getAction() {
        return LauncherUtil.LAUNCH_ACTIVITY_TRANSPARENT;
    }
}
